BAKEXT='.bak'
BINDIR='c:/usr/local/bin'
CC='cl'
CFLAGS='-nologo -MT -O2 -DWIN32=1 -I.'
DEFHASH='english.hash'
DEFLANG='english.aff'
EXEEXT='.exe'
HASHSUFFIX='.hash'
INSTALL='cp'
LANGUAGES='{american,MASTERDICTS=american.med,HASHFILES=americanmed.hash,EXTRADICT=}'
LIBDIR='c:/usr/local/lib'
LIBES=''
LINK='cp'
LINT='lint'
LINTFLAGS=''
LOOK_XREF='.IR look (1),'
MAKE_SORTTMP='-T ${TMPDIR-/tmp}'
MAN1DIR='c:/usr/local/man/man1'
MAN1EXT='.1'
MAN45DIR='c:/usr/local/man/man5'
MAN45EXT='.5'
MAN45SECT='5'
MASTERHASH='americanmed.hash'
MSGLANG='english'
POUNDBANG='#!/bin/sh'
REGLIB=''
STATSUFFIX='.stat'
SPELL_XREF='.\134\042'
TERMLIB=''
TIB_XREF='.IR tib " (if available on your system)",'
WORDS='c:/usr/dict/words'
YACC='bison -y'
case "$MAKE_SORTTMP" in "") \
  SORTTMP="-e /!!SORTTMP!!/s/=.*$/=/";; *) SORTTMP=;; esac
